#
# Conditional build:
%bcond_without	debug_asserts
#
Summary:	Tools for the XFS filesystem
Summary(pl.UTF-8):	Narzędzia do systemu plików XFS
Name:		xfsprogs
Version:	6.0.0
Release:	1
License:	LGPL v2.1 (libhandle), GPL v2 (the rest)
Group:		Applications/System
Source0:	https://www.kernel.org/pub/linux/utils/fs/xfs/xfsprogs/%{name}-%{version}.tar.xz
# Source0-md5:	2908d7433cd2aafec9cd69846ef6df9c
Source1:	xfs_lsprojid
Patch0:		%{name}-miscfix-v2.patch
URL:		https://xfs.wiki.kernel.org/
# for <attr/attributes.h>
BuildRequires:	attr-devel
BuildRequires:	autoconf >= 2.69
BuildRequires:	automake
BuildRequires:	bash
BuildRequires:	device-mapper-devel
BuildRequires:	gettext-tools
BuildRequires:	glibc-static
BuildRequires:	inih-devel
BuildRequires:	libblkid-devel
# without .la file so that -static-libtool-libs won't take libedit.a
BuildRequires:	libedit-devel >= 3.1-1.20191231.1
BuildRequires:	libicu-devel
BuildRequires:	libtool
BuildRequires:	libuuid-devel
BuildRequires:	libuuid-static
BuildRequires:	pkgconfig
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.402
BuildRequires:	systemd-devel
BuildRequires:	userspace-rcu-devel
BuildRequires:	userspace-rcu-static
BuildRequires:	sed >= 4.0
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
Obsoletes:	xfsprogs-initrd < 3.1.11-2
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%if "%{pld_release}" == "ac"
# libtool in ac doesn't do the reordering of args properly
%define		filterout_ld -Wl,--as-needed
%endif

%description
A set of commands to use the XFS filesystem, including mkfs.xfs.

XFS is a high performance journaling filesystem which originated on
the SGI IRIX platform. It is completely multi-threaded, can support
large files and large filesystems, extended attributes, variable block
sizes, is extent based, and makes extensive use of Btrees
(directories, extents, free space) to aid both performance and
scalability.

This implementation is on-disk compatible with the IRIX version of
XFS.

%description -l pl.UTF-8
Zbiór komend do użytku z systemem plików XFS, włączając w to mkfs.xfs.

XFS jest wysoko wydajnym systemem plików z kroniką, który oryginalnie
był używany na platformie SGI IRIX. Jest to w pełni wielowątkowy,
obsługujący wielkie pliki oraz wielkie systemy, o rozszerzonych
atrybutach, zmiennych wielkościach bloków, mocno wykorzystujący
B-drzewa by uzyskać wysoką wydajność oraz skalowalność.

%package scrub
Summary:	xfs_scrub - XFS online check and repair feature (EXPERIMENTAL!)
Summary(pl.UTF-8):	xfs_scrub - sprawdzanie i naprawianie zamontowanego systemu plików XFS (EKSPERYMENTALNE!)
Group:		Applications/System
Requires:	%{name} = %{version}-%{release}
Requires:	systemd-units >= 38

%description scrub
xfs_scrub is an XFS online check and repair feature.

WARNING: EXPERIMENTAL, use at your own risk!

%description scrub -l pl.UTF-8
xfs_scrub służy do sprawdzania i naprawiania zamontowanego systmeu
plików XFS w locie.

UWAGA: EXPERIMENTALNE, użycie na własne ryzyko!

%package devel
Summary:	Header files and libraries to develop XFS software
Summary(pl.UTF-8):	Pliki nagłówkowe i biblioteki
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libuuid-devel
Requires:	linux-libc-headers

%description devel
Header files and libraries to develop software which operates on XFS
filesystems.

%description devel -l pl.UTF-8
Pliki nagłówkowe i biblioteki potrzebne do rozwoju oprogramowania
operującego na systemie plików XFS.

%package static
Summary:	Static XFS software libraries
Summary(pl.UTF-8):	Biblioteki statyczne do XFS
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static XFS software libraries.

%description static -l pl.UTF-8
Biblioteki statyczne do XFS.

%prep
%setup -q
%patch0 -p1

%{__sed} -i -e '1s,/usr/bin/env python3,%{__python3},' scrub/xfs_scrub_all.in tools/xfsbuflock.py

%build
%{__aclocal} -I m4
%{__autoconf}
%configure \
	DEBUG="%{?with_debug_asserts:-DDEBUG}%{!?with_debug_asserts:-DNDEBUG}" \
	OPTIMIZER="%{rpmcflags}" \
	--enable-blkid \
	--enable-editline \
	--enable-gettext \
	--enable-libicu \
	--disable-lto \
	--enable-scrub=yes

%{__make} \
	V=1

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT/etc/cron.d

DIST_ROOT=$RPM_BUILD_ROOT
DIST_INSTALL=$(pwd)/install.manifest
DIST_INSTALL_DEV=$(pwd)/install-dev.manifest
export DIST_ROOT DIST_INSTALL DIST_INSTALL_DEV

%{__make} install \
	DIST_MANIFEST="$DIST_INSTALL"
%{__make} install-dev \
	DIST_MANIFEST="$DIST_INSTALL_DEV"

install -p %{SOURCE1} $RPM_BUILD_ROOT%{_sbindir}/xfs_lsprojid

# adjust symlink to point to actual library, not libhandle.so symlink, which we remove afterwards
ln -sf /%{_lib}/$(basename $RPM_BUILD_ROOT/%{_lib}/libhandle.so.*.*.*) \
	 $RPM_BUILD_ROOT%{_libdir}/libhandle.so
# adjust library path used at link time
%{__sed} -i -e "s|libdir='/%{_lib}'|libdir='%{_libdir}'|" \
	$RPM_BUILD_ROOT%{_libdir}/libhandle.la
# already in /usr
%{__rm} $RPM_BUILD_ROOT/%{_lib}/libhandle.{so,la,a}

# install cron file
%{__mv} $RPM_BUILD_ROOT{%{_libdir}/%{name}/xfs_scrub_all.cron,/etc/cron.d/xfs_scrub_all}

# (config file paths are specified in libfrog/projects.c)
echo "#10:/mnt/ftp/roman"  >> $RPM_BUILD_ROOT/etc/projects
echo "#ftproman:10" >> $RPM_BUILD_ROOT/etc/projid

%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post scrub
%systemd_reload

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc README doc/{CHANGES,CREDITS}
%config(noreplace) %verify(not md5 mtime size) /etc/projects
%config(noreplace) %verify(not md5 mtime size) /etc/projid
%attr(755,root,root) /sbin/fsck.xfs
%attr(755,root,root) /sbin/mkfs.xfs
%attr(755,root,root) /sbin/xfs_repair
%attr(755,root,root) %{_sbindir}/xfs_*
%exclude %{_sbindir}/xfs_scrub*
%attr(755,root,root) /%{_lib}/libhandle.so.*.*
%attr(755,root,root) %ghost /%{_lib}/libhandle.so.1
%{_datadir}/%{name}
%dir %{_libdir}/%{name}
%attr(755,root,root) %{_libdir}/%{name}/xfs_scrub_fail
%{_mandir}/man5/projects.5*
%{_mandir}/man5/projid.5*
%{_mandir}/man5/xfs.5*
%{_mandir}/man8/fsck.xfs.8*
%{_mandir}/man8/mkfs.xfs.8*
%{_mandir}/man8/xfs_*.8*
%exclude %{_mandir}/man8/xfs_scrub*.8*

%files scrub
%defattr(644,root,root,755)
%attr(755,root,root) %{_sbindir}/xfs_scrub
%attr(755,root,root) %{_sbindir}/xfs_scrub_all
%{systemdunitdir}/xfs_scrub@.service
%{systemdunitdir}/xfs_scrub_all.service
%{systemdunitdir}/xfs_scrub_all.timer
%{systemdunitdir}/xfs_scrub_fail@.service
%config(noreplace) %verify(not md5 mtime size) /etc/cron.d/xfs_scrub_all
%{_mandir}/man8/xfs_scrub.8*
%{_mandir}/man8/xfs_scrub_all.8*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libhandle.so
%{_libdir}/libhandle.la
%{_includedir}/xfs
%{_mandir}/man2/ioctl_xfs_ag_geometry.2*
%{_mandir}/man2/ioctl_xfs_bulkstat.2*
%{_mandir}/man2/ioctl_xfs_fsbulkstat.2*
%{_mandir}/man2/ioctl_xfs_fscounts.2*
%{_mandir}/man2/ioctl_xfs_fsgeometry.2*
%{_mandir}/man2/ioctl_xfs_fsgetxattr.2*
%{_mandir}/man2/ioctl_xfs_fsgetxattra.2*
%{_mandir}/man2/ioctl_xfs_fsinumbers.2*
%{_mandir}/man2/ioctl_xfs_fssetxattr.2*
%{_mandir}/man2/ioctl_xfs_getbmap.2*
%{_mandir}/man2/ioctl_xfs_getbmapa.2*
%{_mandir}/man2/ioctl_xfs_getbmapx.2*
%{_mandir}/man2/ioctl_xfs_getresblks.2*
%{_mandir}/man2/ioctl_xfs_goingdown.2*
%{_mandir}/man2/ioctl_xfs_inumbers.2*
%{_mandir}/man2/ioctl_xfs_scrub_metadata.2*
%{_mandir}/man2/ioctl_xfs_setresblks.2*
%{_mandir}/man3/*handle.3*
%{_mandir}/man3/xfsctl.3*

%files static
%defattr(644,root,root,755)
%{_libdir}/libhandle.a
%changelog
* Tue Nov 15 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/xfsprogs.git;a=log;h=master

* Tue Nov 15 2022 Jan Palus <atler@pld-linux.org> 7153178
- BR: pkgconfig systemd-devel

* Tue Nov 15 2022 Jan Palus <atler@pld-linux.org> 64d1bb2
- up to 6.0.0

* Tue Aug 23 2022 Jan Palus <atler@pld-linux.org> 7d20b83
- R: linux-libc-headers in -devel; rel 3

* Sun Aug 21 2022 Jakub Bogusz <qboosh@pld-linux.org> d70e156
- updated pl.po-update patch

* Wed Aug 17 2022 Jan Palus <atler@pld-linux.org> 980a12a
- Release 2 (by relup.sh)

* Sun Aug 14 2022 Jan Palus <atler@pld-linux.org> b8ddc03
- up to 5.19.0

* Mon Jun 13 2022 Jakub Bogusz <qboosh@pld-linux.org> c942200
- updated pl.po-update patch

* Sun Jun 12 2022 Jan Palus <atler@pld-linux.org> b93753b
- up to 5.18.0

* Fri Jun 03 2022 Jan Palus <atler@pld-linux.org> 5f6da31
- icu rebuild

* Sat May 07 2022 Jakub Bogusz <qboosh@pld-linux.org> 8cf0c6c
- updated pl.po-update patch

* Thu May 05 2022 Arkadiusz Miśkiewicz <arekm@maven.pl> f171221
- Up to 5.16.0.

* Fri Apr 22 2022 Jan Palus <jpalus@fastmail.com> 5995cbe
- up to 5.15.0

* Tue Feb 08 2022 Jan Rękorajski <baggins@pld-linux.org> dbd7f2c
- Release 3 (by relup.sh)

* Sat Jan 15 2022 Jan Palus <atler@pld-linux.org> 7b09b6a
- icu rebuild

* Sun Dec 19 2021 Jakub Bogusz <qboosh@pld-linux.org> 2924c89
- updated pl.po-update patch
- versioned Obsoletes

* Thu Dec 09 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> 9f476f9
- Open target file in read only mode (fixes case of running it from non-root for root owned files etc).

* Tue Dec 07 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> 5ce4484
- Up to 5.14.2.

* Sun Dec 05 2021 Adam Gołębiowski <adamg@pld-linux.org> 2849b9f
- updated to 5.14.1
- BR: userspace-rcu-devel, userspace-rcu-static
- parallel build looks fine, reenable it

* Sat Aug 21 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> 34474d6
- Rel 1

* Sat Aug 21 2021 Jakub Bogusz <qboosh@pld-linux.org> 21b95c6
- updated pl.po-update patch

